@@ -7,7 +7,7 @@
 #'
 #' AICc was proposed by Nariaki Sugiura in 1978 and is used on small samples.
 #'
-#' @aliases AICc AICc.default
+#' @aliases AICc
 #' @param object Time series model.
 #' @param ...  Some stuff.
 #' @return This function returns numeric value.
@@ -36,7 +36,7 @@ AICc <- function(object, ...) UseMethod("AICc")
 #' \code{modelType()} is useful only for ETS and CES. They return \code{NA} for other functions.
 #' This can also be applied to \code{ets()} function from forecast package.
 #'
-#' @aliases orders orders.default
+#' @aliases orders
 #' @param object Model estimated using one of the functions of smooth package.
 #' @param ... Currently nothing is accepted via ellipsis.
 #' @return     Either vector or list with values is returned.
@@ -73,25 +73,16 @@ AICc <- function(object, ...) UseMethod("AICc")
 #' @export orders
 orders <- function(object, ...) UseMethod("orders")
 
-#' @aliases lags.default
+#' @aliases lags
 #' @rdname orders
 #' @export lags
 lags <- function(object, ...) UseMethod("lags")
 
-#' @aliases modelType.default
+#' @aliases modelType
 #' @rdname orders
 #' @export modelType
 modelType <-  function(object, ...) UseMethod("modelType")
 
-##### model.type() is depricated function. Will be removed later #####
-#' @aliases model.type
-#' @rdname orders
-#' @export model.type
-model.type <- function(object, ...){
-    warning("This function is depricated. Please, use modelType() instead.",call.=FALSE);
-    modelType(object, ...);
-}
-
 ##### Likelihood function and stuff #####
 #' @importFrom stats logLik
 #' @export
@@ -139,7 +130,7 @@ nobs.iss <- function(object, ...){
 #' This is a very basic and a simple function which does what it says:
 #' extracts number of parameters in the estimated model.
 #'
-#' @aliases nParam nParam.default
+#' @aliases nParam
 #' @param object Time series model.
 #' @param ... Some other parameters passed to the method.
 #' @return This function returns a numeric value.
@@ -185,7 +176,7 @@ nParam.iss <- function(object, ...){
 #' values are biased, so you would possibly need to take number of degrees of freedom
 #' into account in order to have an unbiased estimator.
 #'
-#' @aliases pointLik pointLik.default
+#' @aliases pointLik
 #' @param object Time series model.
 #' @param ...  Some stuff.
 #' @return This function returns a vector.
@@ -847,6 +838,9 @@ print.smooth.sim <- function(x, ...){
             }
             cat(paste0("True likelihood: ",round(x$logLik,3),"\n"));
         }
+        else if(gregexpr("SMA",x$model)!=-1){
+            cat(paste0("True likelihood: ",round(x$logLik,3),"\n"));
+        }
     }
 }
 
@@ -966,6 +960,14 @@ simulate.smooth <- function(object, nsim=1, seed=NULL, obs=NULL, ...){
                                  iprob=object$iprob[length(object$iprob)], randomizer=randomizer, mean=0, sd=sqrt(object$s2),...);
 
     }
+    else if(gregexpr("SMA",object$model)!=-1){
+        orders <- orders(object);
+        randomizer <- "rnorm";
+        simulatedData <- sim.sma(order=orders,
+                                 frequency=frequency(object$actuals),
+                                 initial=object$initial, obs=obs, nsim=nsim,
+                                 iprob=object$iprob[length(object$iprob)], randomizer=randomizer, mean=0, sd=sqrt(object$s2),...);
+    }
     else{
         model <- substring(object$model,1,unlist(gregexpr("\\(",object$model))[1]-1);
         message(paste0("Sorry, but simulate is not yet available for the model ",model,"."));
