@@ -30,3 +30,10 @@ testModel <- ves(Y,"AAN", cfType="t", silent=TRUE);
 test_that("Test VES with a trace cost function", {
     expect_match(testModel$cfType, "trace");
 })
+
+# Test VES with a dependent transition and independent intervals
+testModel <- ves(Y,"AAN", transition="d", intervals="i", silent=TRUE);
+test_that("Test VES with a dependent transition and independent intervals", {
+    expect_false(isTRUE(all.equal(testModel$transition[1,4], 0)));
+    expect_equal(dim(testModel$PI),c(10,4));
+})
